from .alqueda import alqueda

error_correction_learning_algo = alqueda.error_correction_learning_algo
memory_based_algo = alqueda.memory_based_algo
hebbian_learning = alqueda.hebbian_learning
gate_operation_single_layer = alqueda.gate_operation_single_layer
mlp_xor_gate = alqueda.mlp_xor_gate
xor_with_rbf = alqueda.xor_with_rbf
hebbian_vs_pca = alqueda.hebbian_vs_pca
som = alqueda.som
bptt_rnn = alqueda.bptt_rnn
hopfield = alqueda.hopfield
neural_network_mnsit = alqueda.neural_network_mnsit
optimization_methods = alqueda.optimization_methods
resNet_alexNet_vgg_placenet = alqueda.resNet_alexNet_vgg_placenet
vgg = alqueda.vgg
rnn_lstm = alqueda.rnn_lstm